Index: tests/compiler/dart2js/compiler_alt.dart |
diff --git a/tests/compiler/dart2js/compiler_alt.dart b/tests/compiler/dart2js/compiler_alt.dart |
index 030e584ae350b67dd2d366de831f707f25cc7336..5296de0802bfa42e8c72cb983282b3bf0731ae71 100644 |
--- a/tests/compiler/dart2js/compiler_alt.dart |
+++ b/tests/compiler/dart2js/compiler_alt.dart |
@@ -6,14 +6,14 @@ |
/// for later inspection. |
/// |
/// Use this in testing to inspect the compiler after compilation by setting |
/// the `compileFunc` variable in `package:compiler/implementation/dart2js.dart` |
/// to [compiler] before calling the `internalMain` function. |
library dart2js.alt; |
import 'dart:async'; |
import 'package:compiler/compiler.dart'; |
-import 'package:compiler/implementation/apiimpl.dart'; |
+import 'package:compiler/src/apiimpl.dart'; |
Compiler compiler; |
@@ -6,14 +6,14 @@ |
/// |
/// Use this in testing to inspect the compiler after compilation by setting |
-/// the `compileFunc` variable in `package:compiler/implementation/dart2js.dart` |
+/// the `compileFunc` variable in `package:compiler/src/dart2js.dart` |
/// to [compiler] before calling the `internalMain` function. |
library dart2js.alt; |